@@ -22,10 +22,6 @@ OC.L10N.register(
     "Saved" : "Vistað",
     "Download" : "Niðurhal",
     "Close" : "Loka",
-    "filter" : "sía",
-    "Language" : "Tungumál",
-    "Subscribe" : "Áskrift",
-    "Got more awesome feeds? Share them with us!" : "Áttu fleiri frábæra fréttastrauma? Deildu þeim með okkur!",
     "No articles available" : "Engar greinar tiltækar",
     "No unread articles available" : "Engar ólesnar greinar tiltækar",
     "Open website" : "Opna vefsvæði",
@@ -60,6 +56,7 @@ OC.L10N.register(
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax eða webcron fannst! Fréttastraumar þínir verða ekki uppfærðir!",
     "How to set up the operating system cron" : "Hvernig á að setja upp cron-þjónustu stýrikerfis",
     "Install and set up a faster parallel updater that uses the News app's update API" : "Setja upp og stilla hraðvirkari samhliða uppfærslueiningu sem notar API-forritsviðmót fréttaforritsins",
+    "Subscribe" : "Áskrift",
     "Web address" : "Veffang",
     "Feed exists already!" : "Streymið er þegar til!",
     "Folder" : "Mappa",
