@@ -4,9 +4,6 @@ OC.L10N.register(
     "Saved" : "Gespäichert",
     "Download" : "Download",
     "Close" : "Zoumaachen",
-    "filter" : "Filter",
-    "Language" : "Sprooch",
-    "Subscribe" : "Umellen",
     "No articles available" : "Keng Artikelen verfügbar",
     "Open website" : "Oppe Websäit",
     "by" : "vun",
@@ -23,6 +20,7 @@ OC.L10N.register(
     "Refresh" : "Opfrëschen",
     "Load next folder" : "Den nächsten Dossier lueden",
     "Load previous folder" : "Den Dossier vu virdrun lueden",
+    "Subscribe" : "Umellen",
     "Web address" : "Link",
     "Folder" : "Dossier",
     "No folder" : "Keen Dossier",
