@@ -20,10 +20,6 @@ OC.L10N.register(
     "Saved" : "U ruajt",
     "Download" : "Shkarko",
     "Close" : "Mbylle",
-    "filter" : "filtër",
-    "Language" : "Gjuhë",
-    "Subscribe" : "Pajtohuni",
-    "Got more awesome feeds? Share them with us!" : "Keni prurje të tjera të mahnitshme? Ndajini me ne!",
     "No articles available" : "Jo artikuj të gatshëm",
     "No unread articles available" : "Pa artikuj të palexuar gati",
     "Open website" : "Hap sajtin",
@@ -58,6 +54,7 @@ OC.L10N.register(
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Zbulohet modaliteti Ajax ose webcron! Feedet tuaja nuk do të përditësohen!",
     "How to set up the operating system cron" : "Si të rregullohet cron-i i sistemit operativ",
     "Install and set up a faster parallel updater that uses the News app's update API" : "Instaloni dhe rregulloni për punë një përditësues paralel më të shpejtë që përdor për përditësime API-n e aplikacionit Lajme",
+    "Subscribe" : "Pajtohuni",
     "Web address" : "Adresë Web",
     "Feed exists already!" : "Prurja ekziston tashmë!",
     "Folder" : "Dosje",
