@@ -22,10 +22,6 @@ OC.L10N.register(
     "Saved" : "Sparad",
     "Download" : "Hämta",
     "Close" : "Stäng",
-    "filter" : "filter",
-    "Language" : "Språk",
-    "Subscribe" : "Prenumerera",
-    "Got more awesome feeds? Share them with us!" : "Har du fler häftiga flöden? Dela dem med oss!",
     "No articles available" : "Inga artiklar tillgängliga",
     "No unread articles available" : "Inga olästa artiklar tillgängliga",
     "Open website" : "Öppna webbplats",
@@ -60,6 +56,7 @@ OC.L10N.register(
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax- eller webcron-läge upptäckt! Dina flöden kommer inte uppdateras!",
     "How to set up the operating system cron" : "Hur man ställer in cron från operativsystemet",
     "Install and set up a faster parallel updater that uses the News app's update API" : "Installera och konfigurera en snabbare parallell uppdaterare som använder programmet Nyheter uppdatering API",
+    "Subscribe" : "Prenumerera",
     "Web address" : "Webbadress",
     "Feed exists already!" : "Flödet finns redan!",
     "Folder" : "Mapp",
