@@ -10,9 +10,6 @@ OC.L10N.register(
     "Saved" : "已儲存",
     "Download" : "下載",
     "Close" : " 關閉",
-    "filter" : "過濾(篩選)",
-    "Language" : "語言",
-    "Subscribe" : "訂閱",
     "No articles available" : "沒有文章",
     "No unread articles available" : "沒有未讀文章",
     "Open website" : "開啟網站",
@@ -44,6 +41,7 @@ OC.L10N.register(
     "Scroll to active navigation entry" : "捲動至使用中的導覽項",
     "Focus search field" : "進入搜尋框",
     "Mark current article's feed/folder read" : "標示目前文章所在的饋流或資料夾為已讀",
+    "Subscribe" : "訂閱",
     "Web address" : "網頁位址",
     "Feed exists already!" : "訂閱已經存在！",
     "Folder" : "資料夾",
